/*******************************************************************************
 * Copyright (C) 2004-2008 Intel Corp. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 *   - Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 * 
 *   - Redistributions in binary form must reproduce the above copyright notice,
 *     this list of conditions and the following disclaimer in the documentation
 *     and/or other materials provided with the distribution.
 * 
 *   - Neither the name of Intel Corp. nor the names of its
 *     contributors may be used to endorse or promote products derived from this
 *     software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL Intel Corp. OR THE CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *******************************************************************************/

#ifndef _IME_GUI_NOTIFICATIONS_H
#define _IME_GUI_NOTIFICATIONS_H

#include <gtkmm.h>
#include "AMTStatusData.h"
#ifdef WITH_TPM
#include "TPMStatusData.h"
#endif

#define MESGUI_NOTIFY_INFO       0
#define MESGUI_NOTIFY_WARNING    (1 << 0)
#define MESGUI_NOTIFY_QUESTION   (1 << 1)
#define MESGUI_NOTIFY_ERROR      (1 << 2)
#define MESGUI_NOTIFY_USEMARKUP  (1 << 4)

#define MESGUI_SKU_AMT      (1 << 0)
#ifdef WITH_TPM
#define MESGUI_SKU_TPM      (1 << 1)
#endif
#define MESGUI_SKU_AMTFUND  (1 << 2)

//*****************************************************************************
//
// Class:	    IMEGuiNotifications
//
// Description:	    This is an interface class that represents all the messages
//                  that the gui of the MEStatus application can get from its
//                  logic.
//
//*****************************************************************************
class IMEGuiNotifications
{
public:
	virtual ~IMEGuiNotifications() {};

	virtual void OnAMTStatusData(AMTStatusData &amtData) = 0;
#ifdef WITH_TPM
	virtual void OnTPMStatusData(TPMStatusData &tpmData) = 0;
#endif
	virtual void LoadInitialEventHistoryData() = 0;
	virtual void OnEventHistory() = 0;
	virtual bool Notify(const Glib::ustring &title, const Glib::ustring &body, int show = MESGUI_NOTIFY_INFO) = 0;
	virtual void PresentStatusDialog() = 0;
	virtual void OnSku(unsigned int sku) = 0;
};

#endif //_IME_GUI_NOTIFICATIONS_H
