/*******************************************************************************
 * Copyright (C) 2004-2008 Intel Corp. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 *   - Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 * 
 *   - Redistributions in binary form must reproduce the above copyright notice,
 *     this list of conditions and the following disclaimer in the documentation
 *     and/or other materials provided with the distribution.
 * 
 *   - Neither the name of Intel Corp. nor the names of its
 *     contributors may be used to endorse or promote products derived from this
 *     software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL Intel Corp. OR THE CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *******************************************************************************/

#ifndef _IME_ICON_NOTIFICATIONS_H
#define _IME_ICON_NOTIFICATIONS_H

#include <gtkmm.h>
#include "AMTStatusData.h"

#define SICON_NOTIFY_SHOW_SHOW     (1 << 0)
#define SICON_NOTIFY_SHOW_CRITICAL (1 << 1)
#define SICON_NOTIFY_SHOW_LOW      (1 << 2)
#define SICON_NOTIFY_SHOW_NOBUBBLE (1 << 3)

#define SICON_ST_UNK 0
#define SICON_ST_ON  1
#define SICON_ST_OFF 2
#define SICON_ST_OFF_SOME 3

//*****************************************************************************
//
// Class:	    IMEIconNotifications
//
// Description:	    This is an interface class that represents all the messages
//                  that the icon of the MEStatus application can get from its
//                  logic.
//
//*****************************************************************************
class IMEIconNotifications
{
public:
	virtual ~IMEIconNotifications() {};

	virtual void SetState(int sist) = 0;
	virtual bool Notify(const gchar *title, const gchar *body, bool warn = true, int show = SICON_NOTIFY_SHOW_SHOW) = 0;
	virtual void SetNotifyWarnPermition(bool permit) = 0;
};

#endif //_IME_ICON_NOTIFICATIONS_H
