/*******************************************************************************
 * Copyright (C) 2004-2008 Intel Corp. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 *   - Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 * 
 *   - Redistributions in binary form must reproduce the above copyright notice,
 *     this list of conditions and the following disclaimer in the documentation
 *     and/or other materials provided with the distribution.
 * 
 *   - Neither the name of Intel Corp. nor the names of its
 *     contributors may be used to endorse or promote products derived from this
 *     software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL Intel Corp. OR THE CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *******************************************************************************/

//******************************************************************************
//
// File:		MEStatusIcon.h
//
// Description:		Interface for MEStatusIcon class
//                      The Icon of the MEStatus application.
//
//******************************************************************************

#ifndef _ME_STATUS_ICON_H
#define _ME_STATUS_ICON_H

#include <gtk/gtkversion.h>
#if (!GTK_CHECK_VERSION(2,10,0))
#include <igtkxmm/statusicon.h>
#endif
#include <gtkmm.h>
#include <libnotify/notify.h>
#ifdef HAVE_OLD_BUGGY_NOTIFY
G_END_DECLS
#endif
#include "IMEIconCommands.h"
#include "IMEIconNotifications.h"
#include "Semaphore.h"

/* MEStatusIcon: This class is the notification icon with popup menu.
 */
class MEStatusIcon: public IMEIconNotifications
{
public:
	//ctor
	MEStatusIcon();
	//dtor
	virtual ~MEStatusIcon();
	/*Init: Initialize the icon. pMEIconCommands is a pointer to the commands object, which must
		already be initialized. strError is a reference to a string that will hold an error message
		in case initialization fails.*/
	bool Init(IMEIconCommands *pMEIconCommands, Glib::ustring &strError);

	//notification bubble show callback
	static void NotificationShowCb(NotifyNotification *notification, gpointer user_data);

	/*From IMEIconNotifications*/
	//Notification of AMT state change
	virtual void SetState(int sist);
	//Show notification bubble
	virtual bool Notify(const gchar *title, const gchar *body,
			    bool warn = true, int show = SICON_NOTIFY_SHOW_SHOW);
	//Set permition for change icon to warn state
	virtual void SetNotifyWarnPermition(bool permit);

protected:

	enum SIconState {
		SICON_STATE_INITIAL = 0,
		SICON_STATE_UNKNOWN,
		SICON_STATE_OFF,
		SICON_STATE_OFF_SOME,
		SICON_STATE_ON
	};

	/*Signal handlers*/
	//The "show status" option from the popup menu was selected
	virtual void OnMenuShowStatus();
	//The "exit" option from the popup menu was selected
	virtual void OnMenuExit();

	//The status icon was clicked
	static void OnStatusIconClicked(GtkStatusIcon* icon,
					gpointer func_data);
	//The status icon was single-clicked
	bool IconLClicked();
	//The status icon was right-clicked
	static void OnStatusIconPopupMenu(GtkStatusIcon *status_icon,
					  guint          button,
					  guint          activate_time,
					  gpointer       user_data);

	//notification bubble close callback
	static void NotificationClosedCb(NotifyNotification *notification, gpointer user_data);

private:
	//init status icon
	bool initStatusIcon(Glib::ustring &strError);
	//init status icon popup menu
	bool initPopupMenu(Glib::ustring &strError);

	//update status icon image
	void updateStatusIcon();

	//Data members:
	//Pointer to Icon commands that do the actual work
	IMEIconCommands *m_pMEIconCommands;

	Glib::RefPtr<Gtk::StatusIcon> m_statusIcon; //The status icon object

	Glib::RefPtr<Gtk::UIManager> m_refUIManager; //UI manager - needed for popup menu
	Glib::RefPtr<Gtk::ActionGroup> m_refActionGroup; //Action Group - needed for popup menu
	Gtk::Menu *m_pMenuPopup; //The popup menu

	Glib::RefPtr<Gdk::Pixbuf> m_iconOn; // "on" Icon for status icon
	Glib::RefPtr<Gdk::Pixbuf> m_iconOff; // "off" Icon for status icon
	Glib::RefPtr<Gdk::Pixbuf> m_iconAllOff; // "all off" Icon for status icon
	Glib::RefPtr<Gdk::Pixbuf> m_iconUnknown; // "unknown" Icon for status icon
	Glib::RefPtr<Gdk::Pixbuf> m_iconWarn; // "warn" Icon for status icon

	//connection icon click with timeout for double-click emulation
	sigc::connection iconClickActionConnection;

	bool m_canIconWarn; //can Icon be changed to warning state
	bool m_bWarned; //is Icon changed to warning state
	SIconState m_sIconState; //Icon state (not including warning state)
	bool m_bIconVisible;
	Semaphore m_sIconSem;
};

#endif //_ME_STATUS_ICON_H
