/*******************************************************************************
 * Copyright (C) 2004-2008 Intel Corp. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 *   - Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 * 
 *   - Redistributions in binary form must reproduce the above copyright notice,
 *     this list of conditions and the following disclaimer in the documentation
 *     and/or other materials provided with the distribution.
 * 
 *   - Neither the name of Intel Corp. nor the names of its
 *     contributors may be used to endorse or promote products derived from this
 *     software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL Intel Corp. OR THE CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *******************************************************************************/

#ifndef _AMT_STATUS_COLL_H
#define _AMT_STATUS_COLL_H

#include "AMTStatusData.h"
#include "EventNode.h"
#include <list>
#include <string>

class AMTStatusColl
{
public:
	static const std::string defaultLastAMTCollStateFileName;

	// Constructor
	AMTStatusColl();
	// dtor
	virtual ~AMTStatusColl() {};

	int Init(bool autosave = false, std::string fname = AMTStatusColl::defaultLastAMTCollStateFileName);

	//collate new status data with base one, set events
	int Collate(const AMTStatusData &newAMTStatusData, std::list<ATEvents::EventNode> *events);

	//set base status data for collate
	void SetBaseData(const AMTStatusData &newAMTStatusData);

	void GetBaseData(AMTStatusData &baseAMTStatusData);

private:
	bool m_bInitialized;
	bool m_bAutosave;
	bool m_bBaseDataSaved;

	AMTStatusData m_baseAMTStatusData;
	std::string m_lastAMTCollStateFileName;

	int updateBaseData(const AMTStatusData &newAMTStatusData);
	int loadBaseData();
	int saveBaseData();
};

#endif //_AMT_STATUS_COLL_H
