/*******************************************************************************
 * Copyright (C) 2004-2008 Intel Corp. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 *   - Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 * 
 *   - Redistributions in binary form must reproduce the above copyright notice,
 *     this list of conditions and the following disclaimer in the documentation
 *     and/or other materials provided with the distribution.
 * 
 *   - Neither the name of Intel Corp. nor the names of its
 *     contributors may be used to endorse or promote products derived from this
 *     software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL Intel Corp. OR THE CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *******************************************************************************/

#ifndef _AMT_STATUS_DATA_H
#define _AMT_STATUS_DATA_H

#include <ctime>

#define AMTSTATE_NOT_DETECTED 0
#define AMTSTATE_PRE          1
#define AMTSTATE_IN           2
#define AMTSTATE_POST         3
#define AMTSTATE_DISABLED     4
#define AMTSTATE_MEI_DISABLED 5

#define CONTENT_ME_RESET_REASON  (1 << 0)
#define CONTENT_AMT_VER  (1 << 1)
#define CONTENT_PROVMODE (1 << 2)
#define CONTENT_WUISTATE (1 << 3)
#define CONTENT_FEATURES (1 << 4)
#define CONTENT_LANWIRED (1 << 5)
#define CONTENT_LANWLESS (1 << 6)
#define CONTENT_POWERPOL (1 << 7)
#define CONTENT_LMS_VER  (1 << 8)
#define CONTENT_MEI_VER  (1 << 9)
#define CONTENT_HOST_RESET_REASON  (1 << 10)
#define CONTENT_RA       (1 << 11)

#define AMTMODE_NONE       0
#define AMTMODE_ENTERPRISE 1
#define AMTMODE_SB         2
#define AMTMODE_REMOTE     3

#define HOST_RESET_REASON_REMOTE 0
#define HOST_RESET_REASON_OTHER  1

#define ME_RESET_REASON_POWER_UP  0
#define ME_RESET_REASON_FW_RESET  1
#define ME_RESET_REASON_GLOBAL_SYSTEM_RESET  2
#define ME_RESET_REASON_UNKNOWN   3

#define WUISTATE_DISABLED 0
#define WUISTATE_ENABLED  1
#define WUISTATE_TLS      2

#define LAN_DHCP_STATIC   0
//#define LAN_DHCP_DHCP     1
#define LAN_LINK_DOWN     0
//#define LAN_LINK_UP       1
//#define LAN_DHCP_PASIVE   0
#define LAN_DHCP_ACTIVE   1
#define LAN_WIRELESS_DISABLED   0
//#define LAN_WIRELESS_ENABLED    1

#define AMT_NET_CONN_DIRECT               0
#define AMT_NET_CONN_VPN                  1
#define AMT_NET_CONN_OUTSIDE_ENTERPRISE   2

#define RA_CONN_NOT_CONNECTED      0
#define RA_CONN_CONNECTING         1
#define RA_CONN_CONNECTED          2

#define RA_TRIGGER_USER_INITIATED  0
#define RA_TRIGGER_ALERT           1
#define RA_TRIGGER_PROVISIONING    2
#define RA_TRIGGER_PERIODIC        3

#pragma pack(1)

typedef struct _lanC {
	unsigned int  Enabled;
	unsigned int  Ipv4Address;
	unsigned int  DhcpEnabled;
	unsigned char DhcpIpMode;
	unsigned char LinkStatus;
	unsigned char MacAddress[6];
} amtLanSettings;

typedef struct _AMTStatusData {
	time_t         dataTS;
	unsigned int   content;

	unsigned char  amtState;
	unsigned char  lmsRunning;
	unsigned char  provMode;
	unsigned char  webUIState;
	unsigned int   features[3];
	unsigned char  resetMEReason;
	unsigned char  amtNetConnStatus;
	unsigned char  remoteAccessConnStatus;
	unsigned char  remoteAccessConnTrigger;
	unsigned int   resetHostReason;
	unsigned int   resetHostTS;
	amtLanSettings lanWired;
	amtLanSettings lanWireless;
	struct _heciVersion {
		unsigned char major;
		unsigned char minor;
		unsigned char hotfix;
		unsigned short build;
	} heciVersion;
	char           amtVersion[59];
	char           lmsVersion[32];
	char           powerPolicyName[64];
} AMTStatusData;

#pragma pack()

#endif //_AMT_STATUS_DATA_H
