/*******************************************************************************
 * Copyright (C) 2004-2008 Intel Corp. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 *   - Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 * 
 *   - Redistributions in binary form must reproduce the above copyright notice,
 *     this list of conditions and the following disclaimer in the documentation
 *     and/or other materials provided with the distribution.
 * 
 *   - Neither the name of Intel Corp. nor the names of its
 *     contributors may be used to endorse or promote products derived from this
 *     software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL Intel Corp. OR THE CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *******************************************************************************/

#ifndef _MEI_AMT_STATUS_H
#define _MEI_AMT_STATUS_H

#include "AMTStatusData.h"
#include "IMEAMTStatus.h"
#include "StatusCodeDefinitions.h"
#include "PTHICommand.h"
#include "FWULCommand.h"
#include <string>
#include <ctime>
#include <cstdio>

class MEIAMTStatus : public IMEAMTStatus
{
public:
	// Constructor
	MEIAMTStatus(bool verbose = false);
	// dtor
	virtual ~MEIAMTStatus() {};

	/* Reader API */
	//initialize as reader
	bool InitReader() { return true; };
	//deinitialize reader
	void CloseReader() {};
	//get the status data
	bool GetAMTStatusData(AMTStatusData &statusData, bool useFWU = false);

	//set amt disabled state from external FWU
	void SetAMTDisabled(bool disabled) { m_wasAMTDisabled = disabled; };

protected:
	virtual bool isDebugEnabled() { return m_verbose; };
	virtual void debugLog(const char *msg) { if (isDebugEnabled()) { fprintf(stdout, "%s\n", msg); } };

private:
	int getAMTStatus();
	bool isAMTStatusDataAMTVersionValid();
	bool getAMTInfo();
	bool getAMTHECIInfo();
	bool getProvisioningState();
	bool getProvisioningMode();
	bool getFeaturesStatus(); //for Redirection and system defense state
	bool getWebUIState();
	bool getPowerPolicy();
	bool getLastHostResetReason();
	bool getMEResetReason();
	bool getNetworkSettings();
	bool getRemoteAccessStatus();
	bool getLmsVersion();
	bool getLmsVersionCached(time_t ttl = 120);
	bool checkAMTDisabled(bool useFWU);

	AMTStatusData m_AMTStatusData;
	PTHICommand pthiCommand;
	FWULCommand fwulCommand;
	bool m_wasAMTDisabled;
	bool m_verbose;

	time_t m_cachedLmsTs;
	bool   m_cachedLmsIsVer;
	char   m_cachedLmsVer[32];
};

#endif //_MEI_AMT_STATUS_H
