/*******************************************************************************
 * Copyright (C) 2004-2008 Intel Corp. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 *   - Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 * 
 *   - Redistributions in binary form must reproduce the above copyright notice,
 *     this list of conditions and the following disclaimer in the documentation
 *     and/or other materials provided with the distribution.
 * 
 *   - Neither the name of Intel Corp. nor the names of its
 *     contributors may be used to endorse or promote products derived from this
 *     software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL Intel Corp. OR THE CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *******************************************************************************/

#ifndef _EVENT_HISTORY_H
#define _EVENT_HISTORY_H

#include <ctime>
#include <string>
#include <list>

#include "EventNode.h"

namespace ATEvents
{

class EventHistory
{
public:
	static const std::string defaultEHFileName;
	static const std::string userEHStateFileName;

	typedef struct _Event {
		time_t ts;
		unsigned char id;
		unsigned char data[3];
	} Event;

	EventHistory();
	virtual ~EventHistory();

	bool Init(const std::string &filename = EventHistory::defaultEHFileName, unsigned int maxsize = 0);

	int AddEvent(unsigned char id, time_t ts = 0, unsigned char data1 = 0, unsigned char data2 = 0, unsigned char data3 = 0);
	int AddEvent(const EventNode &event);
	int AddEvents(const std::list<EventNode> &events);

	int GetEvents(std::list<EventNode> &events);
	int GetLastEvents(std::list<EventNode> &events, unsigned int maxRsize = 0x100, bool bigskip = true);

	int LoadUserLastEvent(EventNode &readEvent, EventNode &seenEvent);
	int SaveUserLastEvent(const EventNode &readEvent, const EventNode &seenEvent);

private:
	std::string m_fileName;
	std::string m_home;
	unsigned int m_maxSize;

	int checkShorten(unsigned int xsize);
	int addEvent(const Event &ev);
};

}

#endif //_EVENT_HISTORY_H
