/*******************************************************************************
 * Copyright (C) 2004-2008 Intel Corp. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 *   - Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 * 
 *   - Redistributions in binary form must reproduce the above copyright notice,
 *     this list of conditions and the following disclaimer in the documentation
 *     and/or other materials provided with the distribution.
 * 
 *   - Neither the name of Intel Corp. nor the names of its
 *     contributors may be used to endorse or promote products derived from this
 *     software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL Intel Corp. OR THE CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *******************************************************************************/

#ifndef _EVENT_NODE_H
#define _EVENT_NODE_H

#include <ctime>

namespace ATEvents
{

class EventNode
{
public:
	static const unsigned char PROVISIONED               = 1;
	static const unsigned char UNPROVISIONED             = 2;
	static const unsigned char SOL_STARTED               = 3;
	static const unsigned char SOL_FINISHED              = 4;
	static const unsigned char IDER_STARTED              = 5;
	static const unsigned char IDER_FINISHED             = 6;
	static const unsigned char SD_STARTED                = 7;
	static const unsigned char SD_FINISHED               = 8;
	static const unsigned char REMOTE_REBOOT             = 9;
	static const unsigned char AMT_ENABLED               = 10;
	static const unsigned char AMT_DISABLED              = 11;
#ifdef WITH_TPM
	static const unsigned char TPM_OPERATIONAL           = 20;
	static const unsigned char TPM_NOT_DETECTED          = 21;
	static const unsigned char TPM_FAIL                  = 22;
	static const unsigned char TPM_ACTIVE                = 23;
	static const unsigned char TPM_NOT_ACTIVE            = 24;
	static const unsigned char TPM_OWNED                 = 25;
	static const unsigned char TPM_NOT_OWNED             = 26;
	static const unsigned char TPM_ENABLE                = 27;
	static const unsigned char TPM_NOT_ENABLE            = 28;

	static const unsigned char TPM_FAIL_ME_RESET         = 1;
	static const unsigned char TPM_FAIL_HW_FAILURE       = 2;
	static const unsigned char TPM_FAIL_FLASH_CORRUPT    = 3;
	static const unsigned char TPM_FAIL_UNKNOWN          = 4;
#endif

	time_t m_ts;
	unsigned char m_id;
	unsigned char m_data1;
	unsigned char m_data2;
	unsigned char m_data3;

	EventNode(): m_ts(0), m_id(0), m_data1(0), m_data2(0), m_data3(0) {};
	EventNode(unsigned char id, time_t ts = 0,
		  unsigned char data1 = 0, unsigned char data2 = 0, unsigned char data3 = 0):
		  m_ts(ts), m_id(id), m_data1(data1), m_data2(data2), m_data3(data3)
	{
		if (ts == 0) {
			m_ts = time(NULL);
		}
	};
	EventNode(const EventNode &copy)
	{
		m_ts = copy.m_ts;
		m_id = copy.m_id;
		m_data1 = copy.m_data1;
		m_data2 = copy.m_data2;
		m_data3 = copy.m_data3;
	};
	virtual ~EventNode() {};
	EventNode& operator=(const EventNode &copy)
	{
		if (this != &copy) {
			m_ts = copy.m_ts;
			m_id = copy.m_id;
			m_data1 = copy.m_data1;
			m_data2 = copy.m_data2;
			m_data3 = copy.m_data3;
		}
		return *this;
	};
	bool operator==(const EventNode &node)
	{
		if ((m_ts == node.m_ts)
		    && (m_id == node.m_id)
		    && (m_data1 == node.m_data1)
		    && (m_data2 == node.m_data2)
		    && (m_data3 == node.m_data3)
		    )
		{
			return true;
		}
		return false;
	};
	bool operator!=(const EventNode &node)
	{
		if ((m_ts != node.m_ts)
		    || (m_id != node.m_id)
		    || (m_data1 != node.m_data1)
		    || (m_data2 != node.m_data2)
		    || (m_data3 != node.m_data3)
		    )
		{
			return true;
		}
		return false;
	};
	bool empty() { return (!m_ts && !m_id); }
};

}

#endif //_EVENT_NODE_H
