/*******************************************************************************
 * Copyright (C) 2004-2008 Intel Corp. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 *   - Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 * 
 *   - Redistributions in binary form must reproduce the above copyright notice,
 *     this list of conditions and the following disclaimer in the documentation
 *     and/or other materials provided with the distribution.
 * 
 *   - Neither the name of Intel Corp. nor the names of its
 *     contributors may be used to endorse or promote products derived from this
 *     software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL Intel Corp. OR THE CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *******************************************************************************/

#ifndef _MEI_TPM_STATUS_H
#define _MEI_TPM_STATUS_H

#include "TPMStatusData.h"
#include "IMETPMStatus.h"
#include <string>
#ifdef HAVE_TROUSERS_TSS_H
#include <trousers/tss.h>
#endif

#define TPM_VENDOR_INTC 0x494E5443
#define TPM_VENDOR_ATML 0x41544d4c

class TPMStatus : public IMETPMStatus
{
public:
	// Constructor
	TPMStatus();
	// dtor
	virtual ~TPMStatus() {};

	/* Reader API */
	//initialize as reader
	bool InitReader() { return true; };
	//deinitialize reader
	void CloseReader() {};
	//get the status data
	bool GetTPMStatusData(TPMStatusData &statusData, unsigned int vendor = 0);

protected:
	virtual bool isDebugEnabled() { return false; };
	virtual void debugLog(const char *msg) {};

private:
	static const unsigned char req_VER[];
	static const unsigned char req_ENA[];
	static const unsigned char req_ACT[];
	static const unsigned char req_OWN[];
	static const unsigned char req_OPE[];

	int transmit(int fd, unsigned char *blob, unsigned int minDlen);
	int openTPM(int &error, int &idx);
	int getVersion(int fd);
	int getOperationState(int fd);
	int getOwnershipState(int fd);
	int getEnablementState(int fd);
	int getActivationState(int fd);

	std::string getSysFsTpmDev(int idx);
	int getSysCaps(std::string devDir);
	int getSysActive(std::string devDir);
	int getSysEnabled(std::string devDir);
	int getSysOwned(std::string devDir);
	int getSysTempDeactivated(std::string devDir);

#ifdef HAVE_TROUSERS_TSS_H
	TSS_RESULT getTspiVersion(TSS_HCONTEXT &ctx, TSS_HTPM &tpmo);
	TSS_RESULT getTspiOperationState(TSS_HCONTEXT &ctx, TSS_HTPM &tpmo);
	TSS_RESULT getTspiOwnershipState(TSS_HCONTEXT &ctx, TSS_HTPM &tpmo);
	TSS_RESULT getTspiEnablementState(TSS_HCONTEXT &ctx, TSS_HTPM &tpmo);
	TSS_RESULT getTspiActivationState(TSS_HCONTEXT &ctx, TSS_HTPM &tpmo);
	TSS_RESULT getTspiTempActivationState(TSS_HCONTEXT &ctx, TSS_HTPM &tpmo);
#endif

	TPMStatusData m_TPMStatusData;
	static const char *tpmNodes[];
};

#endif //_MEI_TPM_STATUS_H
