/*******************************************************************************
 * Copyright (C) 2004-2008 Intel Corp. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   - Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 *
 *   - Redistributions in binary form must reproduce the above copyright notice,
 *     this list of conditions and the following disclaimer in the documentation
 *     and/or other materials provided with the distribution.
 *
 *   - Neither the name of Intel Corp. nor the names of its
 *     contributors may be used to endorse or promote products derived from this
 *     software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL Intel Corp. OR THE CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *******************************************************************************/

#ifndef _TPM_STATUS_COLL_H
#define _TPM_STATUS_COLL_H

#include "TPMStatusData.h"
#include "EventNode.h"
#include <list>
#include <string>

#define TPM_COLL_OPER_OPERATIONAL     0
#define TPM_COLL_OPER_UNKNOWN        -1
#define TPM_COLL_OPER_NO_OPERATIONAL  (1 << 0)
#define TPM_COLL_OPER_ERROR           ((1 << 1) | (TPM_COLL_OPER_NO_OPERATIONAL))
#define TPM_COLL_OPER_ME_RESET        ((1 << 2) | (TPM_COLL_OPER_ERROR))
#define TPM_COLL_OPER_HW_FAILURE      ((2 << 2) | (TPM_COLL_OPER_ERROR))

class TPMStatusColl
{
public:
	static const std::string defaultLastTPMCollStateFileName;

	// Constructor
	TPMStatusColl();
	// dtor
	virtual ~TPMStatusColl() {};

	int Init(bool autosave = false, std::string fname = TPMStatusColl::defaultLastTPMCollStateFileName);

	//return TPM operational state
	static int TPMOperationalState(const TPMStatusData &someTPMStatusData);

	//collate new status data with base one, set events
	int Collate(const TPMStatusData &newTPMStatusData, std::list<ATEvents::EventNode> *events);

	//set base status data for collate
	void SetBaseData(const TPMStatusData &newTPMStatusData);

	void GetBaseData(TPMStatusData &baseTPMStatusData);

private:
	bool m_bInitialized;
	bool m_bAutosave;
	bool m_bBaseDataSaved;

	TPMStatusData m_baseTPMStatusData;
	std::string m_lastTPMCollStateFileName;

	int updateBaseData(const TPMStatusData &newTPMStatusData);
	int loadBaseData();
	int saveBaseData();
};

#endif //_TPM_STATUS_COLL_H
