/*******************************************************************************
 * Copyright (C) 2004-2008 Intel Corp. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 *   - Redistributions of source code must retain the above copyright notice,
 *     this list of conditions and the following disclaimer.
 * 
 *   - Redistributions in binary form must reproduce the above copyright notice,
 *     this list of conditions and the following disclaimer in the documentation
 *     and/or other materials provided with the distribution.
 * 
 *   - Neither the name of Intel Corp. nor the names of its
 *     contributors may be used to endorse or promote products derived from this
 *     software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL Intel Corp. OR THE CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *******************************************************************************/

#ifndef _TPM_STATUS_DATA_H
#define _TPM_STATUS_DATA_H

#include <ctime>

#define CONTENT_TPM_TCG_VERSION      (1 << 0)
#define CONTENT_TPM_OPERATION_STATE  (1 << 1)
#define CONTENT_TPM_ACTIVATION_STATE (1 << 2)
#define CONTENT_TPM_ENABLEMENT_STATE (1 << 3)
#define CONTENT_TPM_OWNERSHIP_STATE  (1 << 4)
#define CONTENT_TPM_TPM_VERSION      (1 << 5)
#define CONTENT_TPM_OPERATION_SUBSTATES (CONTENT_TPM_ACTIVATION_STATE | CONTENT_TPM_ENABLEMENT_STATE | CONTENT_TPM_OWNERSHIP_STATE)
#define CONTENT_TPM_BUSY             (1 << 6)
#define CONTENT_TPM_TEMP_ACTIV_STATE (1 << 7)

#pragma pack(1)

typedef struct _TPMStatusData
{
	time_t         dataTS;
	unsigned int   content;

	struct _tcgVersion {
		unsigned char  major;
		unsigned char  minor;
		unsigned char  revMajor;
		unsigned char  revMinor;
		unsigned short specLevel;
		unsigned char  errata;
		unsigned char  reserved;
	} TCGVersion;
	unsigned int vendor;
	struct _tpmVersion {
		unsigned short major;
		unsigned short minor;
		unsigned short hotfix;
		unsigned short build;
	} TPMVersion;
	unsigned char operationState[4];
	unsigned char activationState;
	unsigned char enablementState;
	unsigned char ownershipState;
	unsigned char tempActivationState;
} TPMStatusData;

#pragma pack()

#endif //_TPM_STATUS_DATA_H
